dataKey property
String?
get
dataKey
Optional key to fetch the image source dynamically from data.
Implementation
String? get dataKey;
Optional key to fetch the image source dynamically from data.
String? get dataKey;