init method
Initializes the generator with an optional default font.
The font will be used for all text elements unless overridden.
Implementation
Future<void> init({pw.Font? font}) async {
_defaultFont = font;
}
Initializes the generator with an optional default font.
The font will be used for all text elements unless overridden.
Future<void> init({pw.Font? font}) async {
_defaultFont = font;
}