PdfTableBorderStyle enum

Defines the border style for a PDF table element.

Inheritance
Available extensions

Values

none → const PdfTableBorderStyle

No borders shown.

full → const PdfTableBorderStyle

All borders (outer and inner) are shown.

horizontal → const PdfTableBorderStyle

Only horizontal borders between rows are shown.

outer → const PdfTableBorderStyle

Only the outer border of the table is shown.

inner → const PdfTableBorderStyle

Only inner borders between cells are shown.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PdfTableBorderStyle>
A constant List of the values in this enum, in order of their declaration.