PdfTableElement class abstract

Inheritance

Constructors

PdfTableElement({String? visibleIfKey, required String dataSourceKey, required Map<String, String> columns, PdfTableBorderStyle borderStyle})
const
factory
PdfTableElement.fromJson(Map<String, dynamic> json)
factory

Properties

borderStyle PdfTableBorderStyle
Style of borders for the table.
no setter
columns Map<String, String>
Mapping of data keys to column headers (Header -> DataKey).
no setter
copyWith → _$$PdfTableElementImplCopyWith<_$PdfTableElementImpl>
Create a copy of PdfElement with the given fields replaced by the non-null parameter values.
no setter
currentVisibleIfKey String?
Gets the key used for conditional visibility, if applicable for this element.
no setterinherited
dataSourceKey String
Key for the list of objects in the data map to be used as the data source.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleIfKey String?
Optional key to control visibility.
no setter

Methods

map<TResult extends Object?>({required TResult text(PdfTextElement value), required TResult table(PdfTableElement value), required TResult image(PdfImageElement value), required TResult barcode(PdfBarcodeElement value), required TResult divider(PdfDividerElement value), required TResult space(PdfSpaceElement value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? text(PdfTextElement value)?, TResult? table(PdfTableElement value)?, TResult? image(PdfImageElement value)?, TResult? barcode(PdfBarcodeElement value)?, TResult? divider(PdfDividerElement value)?, TResult? space(PdfSpaceElement value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult text(PdfTextElement value)?, TResult table(PdfTableElement value)?, TResult image(PdfImageElement value)?, TResult barcode(PdfBarcodeElement value)?, TResult divider(PdfDividerElement value)?, TResult space(PdfSpaceElement value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult text(String? visibleIfKey, String? text, String? dataKey, PdfTextAlignment alignment)?, TResult table(String? visibleIfKey, String dataSourceKey, Map<String, String> columns, PdfTableBorderStyle borderStyle)?, TResult image(String? visibleIfKey, String? imageSource, String? dataKey, double width, double height, PdfTextAlignment alignment)?, TResult barcode(String? visibleIfKey, String? data, String? dataKey, PdfTextAlignment alignment)?, TResult divider()?, TResult space(double height)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PdfElement to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult text(String? visibleIfKey, String? text, String? dataKey, PdfTextAlignment alignment), required TResult table(String? visibleIfKey, String dataSourceKey, Map<String, String> columns, PdfTableBorderStyle borderStyle), required TResult image(String? visibleIfKey, String? imageSource, String? dataKey, double width, double height, PdfTextAlignment alignment), required TResult barcode(String? visibleIfKey, String? data, String? dataKey, PdfTextAlignment alignment), required TResult divider(), required TResult space(double height)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? text(String? visibleIfKey, String? text, String? dataKey, PdfTextAlignment alignment)?, TResult? table(String? visibleIfKey, String dataSourceKey, Map<String, String> columns, PdfTableBorderStyle borderStyle)?, TResult? image(String? visibleIfKey, String? imageSource, String? dataKey, double width, double height, PdfTextAlignment alignment)?, TResult? barcode(String? visibleIfKey, String? data, String? dataKey, PdfTextAlignment alignment)?, TResult? divider()?, TResult? space(double height)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited