dataSourceKey property
String
get
dataSourceKey
Key for the list of objects in the data map to be used as the data source.
Implementation
String get dataSourceKey;
Key for the list of objects in the data map to be used as the data source.
String get dataSourceKey;