Properties
-
alignment
→ PdfTextAlignment
-
How the text should be aligned.
no setter
-
copyWith
→ _$$PdfTextElementImplCopyWith<_$PdfTextElementImpl>
-
Create a copy of PdfElement
with the given fields replaced by the non-null parameter values.
no setter
-
currentVisibleIfKey
→ String?
-
Gets the key used for conditional visibility, if applicable for this element.
no setterinherited
-
dataKey
→ String?
-
Key to fetch dynamic text from the provided data map.
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
text
→ String?
-
Static text to display.
no setter
-
visibleIfKey
→ String?
-
Optional key to control visibility based on the provided data.
no setter
Methods
-
map<TResult extends Object?>({required TResult text(PdfTextElement value), required TResult table(PdfTableElement value), required TResult image(PdfImageElement value), required TResult barcode(PdfBarcodeElement value), required TResult divider(PdfDividerElement value), required TResult space(PdfSpaceElement value)})
→ TResult
-
inherited
-
mapOrNull<TResult extends Object?>({TResult? text(PdfTextElement value)?, TResult? table(PdfTableElement value)?, TResult? image(PdfImageElement value)?, TResult? barcode(PdfBarcodeElement value)?, TResult? divider(PdfDividerElement value)?, TResult? space(PdfSpaceElement value)?})
→ TResult?
-
inherited
-
maybeMap<TResult extends Object?>({TResult text(PdfTextElement value)?, TResult table(PdfTableElement value)?, TResult image(PdfImageElement value)?, TResult barcode(PdfBarcodeElement value)?, TResult divider(PdfDividerElement value)?, TResult space(PdfSpaceElement value)?, required TResult orElse()})
→ TResult
-
inherited
-
maybeWhen<TResult extends Object?>({TResult text(String? visibleIfKey, String? text, String? dataKey, PdfTextAlignment alignment)?, TResult table(String? visibleIfKey, String dataSourceKey, Map<String, String> columns, PdfTableBorderStyle borderStyle)?, TResult image(String? visibleIfKey, String? imageSource, String? dataKey, double width, double height, PdfTextAlignment alignment)?, TResult barcode(String? visibleIfKey, String? data, String? dataKey, PdfTextAlignment alignment)?, TResult divider()?, TResult space(double height)?, required TResult orElse()})
→ TResult
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this PdfElement to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
when<TResult extends Object?>({required TResult text(String? visibleIfKey, String? text, String? dataKey, PdfTextAlignment alignment), required TResult table(String? visibleIfKey, String dataSourceKey, Map<String, String> columns, PdfTableBorderStyle borderStyle), required TResult image(String? visibleIfKey, String? imageSource, String? dataKey, double width, double height, PdfTextAlignment alignment), required TResult barcode(String? visibleIfKey, String? data, String? dataKey, PdfTextAlignment alignment), required TResult divider(), required TResult space(double height)})
→ TResult
-
inherited
-
whenOrNull<TResult extends Object?>({TResult? text(String? visibleIfKey, String? text, String? dataKey, PdfTextAlignment alignment)?, TResult? table(String? visibleIfKey, String dataSourceKey, Map<String, String> columns, PdfTableBorderStyle borderStyle)?, TResult? image(String? visibleIfKey, String? imageSource, String? dataKey, double width, double height, PdfTextAlignment alignment)?, TResult? barcode(String? visibleIfKey, String? data, String? dataKey, PdfTextAlignment alignment)?, TResult? divider()?, TResult? space(double height)?})
→ TResult?
-
inherited