pdf_layout_kit library
Classes
- PdfBarcodeElement
- PdfDividerElement
- PdfElement
- Represents a single element in a PDF template.
- PdfImageElement
- PdfKitEditor
- The visual editor widget for creating and modifying PDF templates.
- PdfLayoutGenerator
- The main engine responsible for converting a PdfTemplate into a PDF document.
- PdfSpaceElement
- PdfTableElement
- PdfTemplate
- Represents a full PDF template including metadata and a list of elements.
- PdfTextElement
- TemplateStorage
-
A persistent storage service for PdfTemplate using
shared_preferences.
Enums
- AppFont
- Defines the available Google Fonts for the PDF editor.
- LayoutType
- Defines the physical layout and size of the PDF page.
- PdfTableBorderStyle
- Defines the border style for a PDF table element.
- PdfTextAlignment
- Defines the alignment of text or images within a PDF element.