PdfElement.table constructor
const
PdfElement.table({})
A table element that displays a dynamic list of data.
Implementation
const factory PdfElement.table({
/// Optional key to control visibility.
String? visibleIfKey,
/// Key for the list of objects in the data map to be used as the data source.
required String dataSourceKey,
/// Mapping of data keys to column headers (Header -> DataKey).
required Map<String, String> columns,
/// Style of borders for the table.
@Default(PdfTableBorderStyle.full) PdfTableBorderStyle borderStyle,
}) = PdfTableElement;