PdfKitEditor class
The visual editor widget for creating and modifying PDF templates.
Use this widget to embed the editor directly into your application.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PdfKitEditor
Constructors
-
PdfKitEditor({Key? key, required Map<
String, dynamic> data, PdfTemplate? initialTemplate, ValueChanged<PdfTemplate> ? onSave, Future<void> onCustomPrint(Uint8List)?, bool hideDataViewer = false, bool hideSettingsPanel = false, bool showSaveButton = true, bool useDefaultStorage = false, bool showDebugSwitch = false, String? appBarTitle}) -
Creates a PdfKitEditor.
const
Properties
- appBarTitle → String?
-
Custom title to show in the AppBar. Defaults to "PDF Kit Editor".
final
-
data
→ Map<
String, dynamic> -
The data dictionary used for previewing the template.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideDataViewer → bool
-
If true, hides the "View Data" button in the app bar.
final
- hideSettingsPanel → bool
-
If true, hides the side settings panel button and drawer.
final
- initialTemplate → PdfTemplate?
-
The initial template to load. If null, a default template is used.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onCustomPrint
→ Future<
void> Function(Uint8List)? -
Callback triggered for custom print logistics. If null, default printing is used.
final
-
onSave
→ ValueChanged<
PdfTemplate> ? -
Callback triggered when the user saves the template.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDebugSwitch → bool
-
If true, shows the debug switch in the PDF preview toolbar.
final
- showSaveButton → bool
-
If true, shows the "Save Template" button in the settings panel.
final
-
If true, shows the share button in the PDF preview toolbar.
final
- useDefaultStorage → bool
-
If true, automatically loads and saves the template using local storage.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PdfKitEditor> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited