TemplateStorage class
A persistent storage service for PdfTemplate using shared_preferences.
This is used internally by PdfKitEditor when useDefaultStorage is enabled.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearTemplate(
) → Future< void> - Deletes the saved template from local storage.
-
loadTemplate(
) → Future< PdfTemplate?> - Loads and deserializes the PdfTemplate from local storage.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveTemplate(
PdfTemplate template) → Future< void> -
Serializes and saves the
templateto local storage. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited